#
# spec file for package python-dogpile.cache
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-dogpile.cache
Version:        0.6.2
Release:        4.1
Summary:        A caching front-end based on the Dogpile lock
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://bitbucket.org/zzzeek/dogpile.cache
Source:         https://pypi.io/packages/source/d/dogpile.cache/dogpile.cache-%{version}.tar.gz
BuildRequires:  %{python_module Mako}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# NOTE(toabctl): upstream merged dogpile.core into dogpile.cache
# see https://gerrit.sqlalchemy.org/#/c/89/
%ifpython2
Obsoletes:      %{oldpython}-dogpile.core < 0.4.1
Provides:       %{oldpython}-dogpile.core = %{version}
%endif
%ifpython3
Provides:       python3-dogpile.core = %{version}
Obsoletes:      python3-dogpile.core < 0.4.1
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
A caching API built around the concept of a "dogpile lock", which allows
continued access to an expiring data value while a single thread generates a
new value.

%prep
%setup -q -n dogpile.cache-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}/%{_prefix}

%check
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{python_sitelib}/dogpile
%{python_sitelib}/dogpile.cache-%{version}-py%{python_version}.egg-info

%changelog
* Sat May  6 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Mar  1 2017 aloisio@gmx.com
- Converted to single-spec
* Wed Aug 31 2016 tbechtold@suse.com
- update to 0.6.2:
  * Added a new system to allow custom plugins specific to the issue of
    "invalidate the entire region", using a new base class
    :class:`.RegionInvalidationStrategy`. As there are many potential
    strategies to this (special backend function, storing special keys, etc.)
    the mechanism for both soft and hard invalidation is now customizable.
    New approaches to region invalidation can be contributed as documented
    recipes.
  * Added a new cache key generator :func:`.kwarg_function_key_generator`,
    which takes keyword arguments as well as positional arguments into
    account when forming the cache key.
  * Restored some more util symbols that users may have been relying upon
    (although these were not necessarily intended as user-facing):
    ``dogpile.cache.util.coerce_string_conf``,
    ``dogpile.cache.util.KeyReentrantMutex``,
    ``dogpile.cache.util.memoized_property``,
    ``dogpile.cache.util.PluginLoader``,
    ``dogpile.cache.util.to_list``.
  * Drop 0001-Link-moved-functions-in-dogpile.cache.util.patch
    applied upstream
* Mon Jul  4 2016 tbechtold@suse.com
- Use pypi.io for Source url
* Fri Jul  1 2016 tbechtold@suse.com
- dogpile.core was merged into dogpile.cache .
  See https://gerrit.sqlalchemy.org/#/c/89/
  So dogpile.core is no longer a Require.
- Add 0001-Link-moved-functions-in-dogpile.cache.util.patch
  For backward compat.
* Tue Jun  7 2016 aloisio@gmx.com
- Update to version 0.6.1
    bug:
  * Fixed imports for dogpile.core restoring ReadWriteMutex
    and NameRegistry into the base namespace, in addition to
    dogpile.core.nameregistry and dogpile.core.readwrite_lock.
  version 0.6.0
    feature:
  * The dogpile.core library has been rolled in as part of the
    dogpile.cache distribution. The configuration of the
    dogpile name as a namespace package is also removed from
    dogpile.cache. In order to allow existing installations of
    dogpile.core as a separate package to remain unaffected,
    the .core package has been retired within dogpile.cache
    directly; the Lock class is now available directly as
    dogpile.Lock and the additional dogpile.core constructs
    are under the dogpile.util namespace.
    Additionally, the long-deprecated dogpile.core.Dogpile
    and dogpile.core.SyncReaderDogpile classes have been
    removed.
    bug:
  * The Redis backend now creates a copy of the “arguments”
    dictionary passed to it, before popping values out of it.
    This prevents the given dictionary from losing its keys.
  * Fixed bug in “null” backend where NullLock did not accept
    a flag for the NullLock.acquire() method, nor did it return
    a boolean value for “success”.
* Mon Mar  7 2016 tbechtold@suse.com
- update to 0.5.7:
  * Added new parameter :paramref:`.GenericMemcachedBackend.lock_timeout`,
    used in conjunction with :paramref:`.GenericMemcachedBackend.distributed_lock`,
    will specify the timeout used when communicating to the ``.add()`` method of
    the memcached client.
  * Added a new flag :paramref:`.CacheRegion.configure.replace_existing_backend`,
    allows a region to have a new backend replace an existing one.
  * Test suite now runs using py.test.
  * Repaired the :meth:`.CacheRegion.get_multi` method when used with a
    list of zero length against the redis backend.
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 0.5.6:
  * Changed the pickle protocol for the file/DBM backend to
    pickle.HIGHEST_PROTOCOL when producing new pickles, to match
    that of the redis and memorypickle backends. Pull request
    courtesy anentropic.
- additional changes from version 0.5.5:
  * Added new arguments
    CacheRegion.cache_on_arguments.function_key_generator and
    CacheRegion.cache_multi_on_arguments.function_multi_key_generator
    which serve as per-decorator replacements for the region-wide
    CacheRegion.function_key_generator and
    CacheRegion.function_multi_key_generator parameters,
    respectively, so that custom key production schemes can be
    applied on a per-function basis within one region. Pull request
    courtesy Hongbin Lu.
  * Fixed bug where sending -1 for the
    CacheRegion.get_or_create.expiration_time parameter to
    CacheRegion.get_or_create() or
    CacheRegion.get_or_create_multi() would fail to honor the
    setting as “no expiration time”. Pull request courtesy Hongbin
    Lu.
  * The wrap argument is now propagated when calling
    CacheRegion.configure_from_config(). Pull request courtesy
    Jonathan Vanasco.
  * Fixed tests under py.test, which were importing a symbol from
    pytest itself is_unittest which has been removed.
- add fdupes as BuildRequires and call it after install
* Mon Sep 15 2014 tbechtold@suse.com
- Update to version 0.5.4:
  * Added new :class:`.NullBackend`, for testing and cache-disabling
    purposes.  Pull request courtesy Wichert Akkerman.
  * Added missing Mako test dependency to setup.py.
    Pull request courtesy Wichert Akkerman.
  * Fixed bug where calling :meth:`.CacheRegion.get_multi` or
    :meth:`.CacheRegion.set_multi` with an empty list would cause failures
    based on backend.  Pull request courtesy Wichert Akkerman.
  * Added new :paramref:`.RedisBackend.connection_pool` option
    on the Redis backend; this can be passed a ``redis.ConnectionPool``
    instance directly.  Pull request courtesy Masayuko.
  * Added new :paramref:`.RedisBackend.socket_timeout` option
    on the Redis backend.  Pull request courtesy
    Saulius Menkevičius.
  * Added support for tests to run via py.test.
  * Repaired the entry point for Mako templates; the name of the entrypoint
    itself was wrong vs. what was in the docs, but beyond that the entrypoint
    would load the wrong module name.  Pull request courtesy zoomorph.
  * The :func:`.coerce_string_conf` function, which is used by
    :meth:`.Region.configure_from_config`, will now recognize floating point
    values when parsing conf strings and deliver them as such; this supports
    non-integer values such as Redis ``lock_sleep``.  Pullreq courtesy
    Jeff Dairiki.
* Mon Jan 13 2014 dmueller@suse.com
- update to 0.5.3:
  * Fixed bug where the key_mangler would get in the way of usage of the
  async_creation_runner feature within the :meth:`
* Mon Dec 30 2013 dmueller@suse.com
- update to 0.5.2:
  * Added a new argument ``lock_factory`` to the :class:`.DBMBackend`
  * implementation.  This allows for drop-in replacement of the default
  * :class:`.FileLock` backend, which builds on ``os.flock()`` and only
  * supports Unix platforms.
* Mon Oct 21 2013 dmueller@suse.com
- update to 0.5.1:
  * The :meth:`.CacheRegion.invalidate` method now supports an option
  ``hard=True|False``.
  * New dogpile-specific exception classes have been added, so that
  issues like "region already configured", "region unconfigured",
  raise dogpile-specific exceptions.  Other exception classes have
* Mon Sep  2 2013 dmueller@suse.com
- Initial package (0.5.0)
